#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2023  SVA System Vertrieb Alexander GmbH
#                       by gerd.stolz@sva.de
from cmk.gui.plugins.wato.utils import IndividualOrStoredPassword
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextAscii,
)

from cmk.gui.plugins.wato import (
    HostRulespec,
    rulespec_registry,
)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.datasource_programs import RulespecGroupVMCloudContainer


def _valuespec_special_agents_m365_service_health():
    return Dictionary(
        title=_("Monitor state and last of issue of Microsoft 365 services health"),
        elements=[
            ("tenant", TextAscii(
                title=_("Tenant ID / Directory ID"),
                allow_empty=False,
                size=45,
            )),
            ("client", TextAscii(
                title=_("Client ID / Application ID"),
                allow_empty=False,
                size=45,
            )),
            ("secret", IndividualOrStoredPassword(
                title=_("Client Secret"),
                allow_empty=False,
                size=45,
            )),
            ("issue_days", Integer(
                title=_("Number of days to look back for old issue messages"),
                default_value=30,
            )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupVMCloudContainer,
        name="special_agents:m365_service_health",
        valuespec=_valuespec_special_agents_m365_service_health,
    ))
